﻿"use strict";
var tinymce = tinymce || {};

//Register the plugin
tinymce.PluginManager.add('prosodyplugin', function (editor, url) {
    // Add a button that opens a window
    editor.addButton('prosodyplugin', {
        title: 'Prosody',
        image: window.location.protocol + '//' + window.location.hostname + (window.location.port === 80 || window.location.port === 443 ? '' : ':' + window.location.port) + '/EPiServer/Verndale.SSMLEditor/ClientResources/TinyMce/images/prosody-epi.svg',
        onclick: function () {
            if (editor.selection.getNode().nodeName.toLowerCase() === "prosody") {
                var previousValueRate = editor.selection.getNode().getAttribute("rate") !== null ? editor.selection.getNode().getAttribute("rate") : '';
                var previousValuePitch = editor.selection.getNode().getAttribute("pitch") !== null ? editor.selection.getNode().getAttribute("pitch") : '';
                var previousValueVolume = editor.selection.getNode().getAttribute("volume") !== null ? editor.selection.getNode().getAttribute("volume") : '';

                // Open window
                editor.windowManager.open({
                    title: 'Prosody edit plugin',
                    body: [
                        {
                            type: 'listbox',
                            name: 'rate',
                            label: 'Rate',
                            values: [
                                { text: 'None', value: '' },
                                { text: 'Extra Slow', value: 'x-slow' },
                                { text: 'Slow', value: 'slow' },
                                { text: 'Medium', value: 'medium' },
                                { text: 'Fast', value: 'fast' },
                                { text: 'Extra Fast', value: 'x-fast' }
                            ],
                            value: previousValueRate // Sets the default
                        },
                        {
                            type: 'listbox',
                            name: 'pitch',
                            label: 'Pitch',
                            values: [
                                { text: 'None', value: '' },
                                { text: 'Extra Low', value: 'x-low' },
                                { text: 'Low', value: 'low' },
                                { text: 'Medium', value: 'medium' },
                                { text: 'High', value: 'high' },
                                { text: 'Extra High', value: 'x-high' }
                            ],
                            value: previousValuePitch // Sets the default
                        },
                        {
                            type: 'listbox',
                            name: 'volume',
                            label: 'Volume',
                            values: [
                                { text: 'None', value: '' },
                                { text: 'Silent', value: 'silent' },
                                { text: 'Extra Soft', value: 'x-soft' },
                                { text: 'Soft', value: 'soft' },
                                { text: 'Medium', value: 'medium' },
                                { text: 'Loud', value: 'loud' },
                                { text: 'Extra Loud', value: 'x-loud' }
                            ],
                            value: previousValueVolume // Sets the default
                        }
                    ],
                    onsubmit: function (e) {
                        editor.selection.select(editor.selection.getNode(), true);
                        var previousContent = editor.selection.getContent();
                        var tagHtml = '<prosody';

                        if (e.data.rate !== '') {
                            tagHtml += ' rate="' + e.data.rate + '" ';
                        }

                        if (e.data.pitch !== '') {
                            tagHtml += ' pitch="' + e.data.pitch + '" ';
                        }

                        if (e.data.volume !== '') {
                            tagHtml += ' volume="' + e.data.volume + '" ';
                        }

                        tagHtml += '>';

                        // Stores a bookmark of the current selection
                        var bm = editor.selection.getBookmark();
                        editor.selection.getNode().outerHTML = tagHtml + previousContent + '</prosody>';
                        editor.selection.moveToBookmark(bm);
                    }
                });
            } else {
                // Open window
                editor.windowManager.open({
                    title: 'Prosody add plugin',
                    body: [
                        {
                            type: 'listbox',
                            name: 'rate',
                            label: 'Rate',
                            values: [
                                { text: 'None', value: '' },
                                { text: 'Extra Slow', value: 'x-slow' },
                                { text: 'Slow', value: 'slow' },
                                { text: 'Medium', value: 'medium' },
                                { text: 'Fast', value: 'fast' },
                                { text: 'Extra Fast', value: 'x-fast' }
                            ],
                            value: '' // Sets the default
                        },
                        {
                            type: 'listbox',
                            name: 'pitch',
                            label: 'Pitch',
                            values: [
                                { text: 'None', value: '' },
                                { text: 'Extra Low', value: 'x-low' },
                                { text: 'Low', value: 'low' },
                                { text: 'Medium', value: 'medium' },
                                { text: 'High', value: 'high' },
                                { text: 'Extra High', value: 'x-high' }
                            ],
                            value: '' // Sets the default
                        },
                        {
                            type: 'listbox',
                            name: 'volume',
                            label: 'Volume',
                            values: [
                                { text: 'None', value: '' },
                                { text: 'Silent', value: 'silent' },
                                { text: 'Extra Soft', value: 'x-soft' },
                                { text: 'Soft', value: 'soft' },
                                { text: 'Medium', value: 'medium' },
                                { text: 'Loud', value: 'loud' },
                                { text: 'Extra Loud', value: 'x-loud' }
                            ],
                            value: '' // Sets the default
                        }
                    ],
                    onsubmit: function (e) {
                        var tagHtml = '<prosody';

                        if (e.data.rate !== '') {
                            tagHtml += ' rate="' + e.data.rate + '" ';
                        }

                        if (e.data.pitch !== '') {
                            tagHtml += ' pitch="' + e.data.pitch + '" ';
                        }

                        if (e.data.volume !== '') {
                            tagHtml += ' volume="' + e.data.volume + '" ';
                        }

                        tagHtml += '>';

                        editor.selection.setContent(tagHtml + editor.selection.getContent() + '</prosody>');
                        editor.focus();
                    }
                });
            }
        }
    });

    return {
        getMetadata: function () {
            return {
                name: 'Prosody plugin',
                url: 'https://cdisol.blog'
            };
        }
    };
});